@@ -7,17 +7,19 @@
 
 #include "knotifyconfigwidget.h"
 #include "knotifyconfigactionswidget.h"
-#include "knotifyeventlist.h"
 #include "knotifyconfigelement.h"
+#include "knotifyeventlist.h"
 
+#include <QDBusConnectionInterface>
 #include <QDialog>
 #include <QDialogButtonBox>
+#include <QPushButton>
 #include <QVBoxLayout>
-#include <QDBusConnectionInterface>
 
 #include <KLocalizedString>
 
-class KNotifyConfigWidgetPrivate {
+class KNotifyConfigWidgetPrivate
+{
 public:
     KNotifyEventList *eventList;
     KNotifyConfigActionsWidget *actionsconfig;
@@ -28,15 +30,15 @@ public:
 };
 
 KNotifyConfigWidget::KNotifyConfigWidget(QWidget *parent)
-    : QWidget(parent), d(new KNotifyConfigWidgetPrivate)
+    : QWidget(parent)
+    , d(new KNotifyConfigWidgetPrivate)
 {
     d->currentElement = nullptr;
     d->eventList = new KNotifyEventList(this);
     d->eventList->setFocus();
     d->actionsconfig = new KNotifyConfigActionsWidget(this);
     d->actionsconfig->setEnabled(false);
-    connect(d->eventList, SIGNAL(eventSelected(KNotifyConfigElement*)),
-            this, SLOT(slotEventSelected(KNotifyConfigElement*)));
+    connect(d->eventList, SIGNAL(eventSelected(KNotifyConfigElement *)), this, SLOT(slotEventSelected(KNotifyConfigElement *)));
     connect(d->actionsconfig, SIGNAL(changed()), this, SLOT(slotActionChanged()));
 
     QVBoxLayout *layout = new QVBoxLayout(this);
@@ -53,7 +55,7 @@ KNotifyConfigWidget::~KNotifyConfigWidget()
 void KNotifyConfigWidget::setApplication(const QString &app, const QString &context_name, const QString &context_value)
 {
     d->currentElement = nullptr;
-    d->application = app.isEmpty() ? QCoreApplication::instance()->applicationName()  : app;
+    d->application = app.isEmpty() ? QCoreApplication::instance()->applicationName() : app;
     d->contextName = context_name;
     d->contextValue = context_value;
     d->eventList->fill(d->application, d->contextName, d->contextValue);
@@ -76,7 +78,6 @@ void KNotifyConfigWidget::slotEventSelected(KNotifyConfigElement *e)
     } else {
         d->actionsconfig->setEnabled(false);
     }
-
 }
 
 void KNotifyConfigWidget::save()
@@ -86,10 +87,11 @@ void KNotifyConfigWidget::save()
     }
 
     d->eventList->save();
-    emit changed(false);
+    Q_EMIT changed(false);
 
-    //ask KNotification objects to reload their config
-    QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/Config"), QStringLiteral("org.kde.knotification"), QStringLiteral("reparseConfiguration"));
+    // ask KNotification objects to reload their config
+    QDBusMessage message =
+        QDBusMessage::createSignal(QStringLiteral("/Config"), QStringLiteral("org.kde.knotification"), QStringLiteral("reparseConfiguration"));
     message.setArguments(QVariantList() << d->application);
     QDBusConnection::sessionBus().send(message);
 }
@@ -97,7 +99,7 @@ void KNotifyConfigWidget::save()
 void KNotifyConfigWidget::revertToDefaults()
 {
     d->eventList->fill(d->application, d->contextName, d->contextValue, true);
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KNotifyConfigWidget::disableAllSounds()
@@ -107,7 +109,7 @@ void KNotifyConfigWidget::disableAllSounds()
             d->actionsconfig->setConfigElement(d->currentElement);
         }
         d->eventList->updateAllItems();
-        emit changed(true);
+        Q_EMIT changed(true);
     }
 }
 
@@ -122,10 +124,9 @@ KNotifyConfigWidget *KNotifyConfigWidget::configure(QWidget *parent, const QStri
     buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel);
     buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(dialog);
     layout->addWidget(w);
     layout->addWidget(buttonBox);
-    dialog->setLayout(layout);
 
     connect(buttonBox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), w, SLOT(save()));
     connect(buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()), w, SLOT(save()));
@@ -142,10 +143,11 @@ KNotifyConfigWidget *KNotifyConfigWidget::configure(QWidget *parent, const QStri
 
 void KNotifyConfigWidget::slotActionChanged()
 {
-    emit changed(true);   //TODO
+    Q_EMIT changed(true); // TODO
     if (d->currentElement) {
         d->actionsconfig->save(d->currentElement);
         d->eventList->updateCurrentItem();
     }
 }
 
+#include "moc_knotifyconfigwidget.cpp"
